==> rest-assured-2.2.0-sources.jar: com/jayway/restassured/authentication/CertAuthScheme.java <==
package com.jayway.restassured.authentication;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class CertAuthScheme
  extends java.lang.Object  implements
    com.jayway.restassured.authentication.AuthenticationScheme,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getPathToKeyStore() { return null;}
public  void setPathToKeyStore(java.lang.Object value) { }
public  java.lang.String getPassword() { return (java.lang.String)null;}
public  void setPassword(java.lang.String value) { }
public  java.lang.String getKeystoreType() { return (java.lang.String)null;}
public  void setKeystoreType(java.lang.String value) { }
public  int getPort() { return (int)0;}
public  void setPort(int value) { }
public  java.security.KeyStore getTrustStore() { return (java.security.KeyStore)null;}
public  void setTrustStore(java.security.KeyStore value) { }
public  org.apache.http.conn.ssl.X509HostnameVerifier getX509HostnameVerifier() { return (org.apache.http.conn.ssl.X509HostnameVerifier)null;}
public  void setX509HostnameVerifier(org.apache.http.conn.ssl.X509HostnameVerifier value) { }
@java.lang.Override() public  void authenticate(com.jayway.restassured.internal.http.HTTPBuilder httpBuilder) { }
}

==> rest-assured-2.4.1-sources.jar: com/jayway/restassured/authentication/CertAuthScheme.java <==
package com.jayway.restassured.authentication;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class CertAuthScheme
  extends java.lang.Object  implements
    com.jayway.restassured.authentication.AuthenticationScheme,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getPathToKeyStore() { return null;}
public  void setPathToKeyStore(java.lang.Object value) { }
public  java.lang.String getPassword() { return (java.lang.String)null;}
public  void setPassword(java.lang.String value) { }
public  java.lang.String getKeystoreType() { return (java.lang.String)null;}
public  void setKeystoreType(java.lang.String value) { }
public  int getPort() { return (int)0;}
public  void setPort(int value) { }
public  java.security.KeyStore getTrustStore() { return (java.security.KeyStore)null;}
public  void setTrustStore(java.security.KeyStore value) { }
public  org.apache.http.conn.ssl.X509HostnameVerifier getX509HostnameVerifier() { return (org.apache.http.conn.ssl.X509HostnameVerifier)null;}
public  void setX509HostnameVerifier(org.apache.http.conn.ssl.X509HostnameVerifier value) { }
public  org.apache.http.conn.ssl.SSLSocketFactory getSslSocketFactory() { return (org.apache.http.conn.ssl.SSLSocketFactory)null;}
public  void setSslSocketFactory(org.apache.http.conn.ssl.SSLSocketFactory value) { }
@java.lang.Override() public  void authenticate(com.jayway.restassured.internal.http.HTTPBuilder httpBuilder) { }
}
